@@ -83,8 +83,8 @@ class VerifyToken:
             per_status_this = int(per_set_redis_info)
         if per_status_this == 0:
             handle_abnormal(
-                message='无 "{0}-{1}" 的访问权限'.format(
-                    center_name_this, permission_name_this),
+                message='无 "{0}-{1}" 的访问权限({2})'.format(
+                    center_name_this, permission_name_this, per_set_redis_info),
                 status=401,
             )
         return per_status_this
